@@ -7,7 +7,6 @@ Allows to spin up services configured via :code:`docker-compose.yml`.
 
 import subprocess
 
-import blindspin
 import requests
 
 from testcontainers.core.waiting_utils import wait_container_is_ready
@@ -22,7 +21,9 @@ class DockerCompose(object):
     -------
     ::
 
-        with DockerCompose("/home/project", pull=True) as compose:
+        with DockerCompose("/home/project",
+                           compose_file_name=["docker-compose-1.yml", "docker-compose-2.yml"],
+                           pull=True) as compose:
             host = compose.get_service_host("hub", 4444)
             port = compose.get_service_port("hub", 4444)
             driver = webdriver.Remote(
@@ -30,6 +31,9 @@ class DockerCompose(object):
                 desired_capabilities=CHROME,
             )
             driver.get("http://automation-remarks.com")
+            stdout, stderr = compose.get_logs()
+            if stderr:
+                print("Errors\\n:{}".format(stderr))
 
 
     .. code-block:: yaml
@@ -57,7 +61,9 @@ class DockerCompose(object):
             compose_file_name="docker-compose.yml",
             pull=False):
         self.filepath = filepath
-        self.compose_file_name = compose_file_name
+        self.compose_file_names = compose_file_name if isinstance(
+            compose_file_name, (list, tuple)
+        ) else [compose_file_name]
         self.pull = pull
 
     def __enter__(self):
@@ -67,18 +73,32 @@ class DockerCompose(object):
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.stop()
 
+    def docker_compose_command(self):
+        docker_compose_cmd = ['docker-compose']
+        for file in self.compose_file_names:
+            docker_compose_cmd += ['-f', file]
+        return docker_compose_cmd
+
     def start(self):
-        with blindspin.spinner():
-            if self.pull:
-                subprocess.call(["docker-compose", "-f", self.compose_file_name, "pull"],
-                                cwd=self.filepath)
-            subprocess.call(["docker-compose", "-f", self.compose_file_name, "up", "-d"],
-                            cwd=self.filepath)
+        if self.pull:
+            pull_cmd = self.docker_compose_command() + ['pull']
+            subprocess.call(pull_cmd, cwd=self.filepath)
+        up_cmd = self.docker_compose_command() + ['up', '-d']
+        subprocess.call(up_cmd, cwd=self.filepath)
 
     def stop(self):
-        with blindspin.spinner():
-            subprocess.call(["docker-compose", "-f", self.compose_file_name, "down", "-v"],
-                            cwd=self.filepath)
+        down_cmd = self.docker_compose_command() + ['down', '-v']
+        subprocess.call(down_cmd, cwd=self.filepath)
+
+    def get_logs(self):
+        logs_cmd = self.docker_compose_command() + ["logs"]
+        result = subprocess.run(
+            logs_cmd,
+            cwd=self.filepath,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
+        return result.stdout, result.stderr
 
     def get_service_port(self, service_name, port):
         return self._get_service_info(service_name, port)[1]
@@ -87,9 +107,8 @@ class DockerCompose(object):
         return self._get_service_info(service_name, port)[0]
 
     def _get_service_info(self, service, port):
-        cmd_as_list = ["docker-compose", "-f", self.compose_file_name, "port", service, str(port)]
-        output = subprocess.check_output(cmd_as_list,
-                                         cwd=self.filepath).decode("utf-8")
+        port_cmd = self.docker_compose_command() + ["port", service, str(port)]
+        output = subprocess.check_output(port_cmd, cwd=self.filepath).decode("utf-8")
         result = str(output).rstrip().split(":")
         if len(result) == 1:
             raise NoSuchPortExposed("Port {} was not exposed for service {}"
