@@ -1,12 +1,22 @@
 import os
 import sys
 import subprocess
+import logging
 
 LINUX = "linux"
 MAC = "mac"
 WIN = "win"
 
 
+def setup_logger(name):
+    logger = logging.getLogger(name)
+    logger.setLevel(logging.INFO)
+    handler = logging.StreamHandler()
+    handler.setLevel(logging.INFO)
+    logger.addHandler(handler)
+    return logger
+
+
 def os_name():
     pl = sys.platform
     if pl == "linux" or pl == "linux2":
